import { Position } from "./base";
export declare enum AssetHelpSize {
    MINI = 0.5,
    DEFAULT = 1,
    MINI_HD = 2,
    HD = 4,
    FOUR_K = 8
}
export interface IAssetPartMetadata {
    x: number;
    y: number;
    w: number;
    h: number;
}
/**
 * The function scales the dimensions of an asset part metadata object by a given
 * multiplier.
 * @param {IAssetPartMetadata} metadata - An object of type IAssetPartMetadata that
 * contains information about the position and size of an asset part. It has the
 * following properties:
 * @param {number} multiplier - The multiplier is a number that is used to scale
 * the values of the x, y, w, and h properties of the metadata object. It
 * determines how much the values should be increased or decreased. For example, if
 * the multiplier is 2, the values of x, y, w, and
 * @returns an object of type `IAssetPartMetadata` with the `x`, `y`, `w`, and `h`
 * properties scaled by the `multiplier` parameter.
 */
export declare function scaleMetadata(metadata: IAssetPartMetadata, multiplier: number): IAssetPartMetadata;
export type AssetPart = SkinPart | GameskinPart | EmoticonPart | ParticulePart;
export declare enum SkinPart {
    BODY = "body",
    BODY_SHADOW = "body_shadow",
    HAND = "hand",
    HAND_SHADOW = "hand_shadow",
    FOOT = "foot",
    FOOT_SHADOW = "foot_shadow",
    DEFAULT_EYE = "default_eye",
    ANGRY_EYE = "angry_eye",
    PAIN_EYE = "pain_eye",
    HAPPY_EYE = "happy_eye",
    CROSS_EYE = "cross_eye",
    SCARY_EYE = "scary_eye",
    BLINK_EYE = "blink_eye"
}
export type EyeSkinPart = SkinPart.DEFAULT_EYE | SkinPart.ANGRY_EYE | SkinPart.PAIN_EYE | SkinPart.HAPPY_EYE | SkinPart.CROSS_EYE | SkinPart.SCARY_EYE | SkinPart.BLINK_EYE;
export declare const BLINK_SCALE = 0.35;
export declare enum GameskinPart {
    HOOK = "hook",
    HAMMER_CURSOR = "hammer_cursor",
    GUN_CURSOR = "gun_cursor",
    SHOTGUN_CURSOR = "shotgun_cursor",
    GRENADE_CURSOR = "grenade_cursor",
    NINJA_CURSOR = "ninja_cursor",
    LASER_CURSOR = "laser_cursor",
    HAMMER = "hammer",
    GUN = "gun",
    SHOTGUN = "shotgun",
    GRENADE = "grenade",
    NINJA = "ninja",
    LASER = "laser",
    GUN_AMMO = "gun_ammo",
    SHOTGUN_AMMO = "shotgun_ammo",
    GRENADE_AMMO = "grenade_ammo",
    LASER_AMMO = "laser_ammo",
    GUN_PARTICLE_1 = "gun_particle_1",
    GUN_PARTICLE_2 = "gun_particle_2",
    GUN_PARTICLE_3 = "gun_particle_3",
    SHOTGUN_PARTICLE_1 = "shotgun_particle_1",
    SHOTGUN_PARTICLE_2 = "shotgun_particle_2",
    SHOTGUN_PARTICLE_3 = "shotgun_particle_3",
    PARTICLE_1 = "particle_1",
    PARTICLE_2 = "particle_2",
    PARTICLE_3 = "particle_3",
    PARTICLE_4 = "particle_4",
    PARTICLE_5 = "particle_5",
    PARTICLE_6 = "particle_6",
    PARTICLE_7 = "particle_7",
    PARTICLE_8 = "particle_8",
    PARTICLE_9 = "particle_9",
    STAR_1 = "star_1",
    STAR_2 = "star_2",
    STAR_3 = "star_3",
    HEALTH_FULL = "health_full",
    HEALTH_EMPTY = "health_empty",
    ARMOR_FULL = "armor_full",
    ARMOR_EMPTY = "armor_empty",
    HEART = "heart",
    SHIELD = "shield",
    MINUS = "minus",
    NINJA_TIMER = "ninja_timer",
    NINJA_PARTICLE_1 = "ninja_particle_1",
    NINJA_PARTICLE_2 = "ninja_particle_2",
    NINJA_PARTICLE_3 = "ninja_particle_3",
    FLAG_BLUE = "flag_blue",
    FLAG_RED = "flag_red"
}
export type WeaponGameSkinPart = GameskinPart.HAMMER | GameskinPart.GUN | GameskinPart.SHOTGUN | GameskinPart.GRENADE | GameskinPart.NINJA | GameskinPart.LASER;
export declare enum EmoticonPart {
    PART_1_1 = "part_1_1",
    PART_1_2 = "part_1_2",
    PART_1_3 = "part_1_3",
    PART_1_4 = "part_1_4",
    PART_2_1 = "part_2_1",
    PART_2_2 = "part_2_2",
    PART_2_3 = "part_2_3",
    PART_2_4 = "part_2_4",
    PART_3_1 = "part_3_1",
    PART_3_2 = "part_3_2",
    PART_3_3 = "part_3_3",
    PART_3_4 = "part_3_4",
    PART_4_1 = "part_4_1",
    PART_4_2 = "part_4_2",
    PART_4_3 = "part_4_3",
    PART_4_4 = "part_4_4"
}
export declare enum ParticulePart {
    SMALL_1 = "small_1",
    SMALL_2 = "small_2",
    SMALL_3 = "small_3",
    SMALL_4 = "small_4",
    SMALL_5 = "small_5",
    SMALL_6 = "small_6",
    SMALL_7 = "small_7",
    SMALL_8 = "small_8",
    SMALL_9 = "small_9",
    MID_1 = "mid_1",
    MID_2 = "mid_2",
    MID_3 = "mid_3",
    BIG = "big"
}
export declare enum AssetKind {
    SKIN = "skin",
    GAMESKIN = "gameskin",
    EMOTICON = "emoticon",
    PARTICULE = "particule",
    UNKNOWN = "unknown"
}
export interface ITeeHandMetadata extends Position {
    angle: number;
}
export interface ITeeWeaponMetadata {
    hand: ITeeHandMetadata;
    move: Position;
    scaleFactor: number;
}
export declare function getEyesFromEmoticon(emoticonPart: EmoticonPart): EyeSkinPart;
export declare const TEE_WEAPON_METADATA: Record<WeaponGameSkinPart, ITeeWeaponMetadata>;
/**
 * This function retrieves metadata for a specific asset part based on its kind.
 * @param {AssetKind} kind - Asset kind
 * @param {AssetPart} assetPart - Asset part
 * @returns an object of type `IAssetPartMetadata`.
 */
export declare function getAssetPartMetadata(kind: AssetKind, assetPart: AssetPart): IAssetPartMetadata;
/**
 * This function returns metadata for asset parts based on the provided asset kind.
 * @param {AssetKind} kind - Asset kind
 * @returns Every parts metadata
 */
export declare function getAssetPartsMetadata(kind: AssetKind): Record<string, IAssetPartMetadata>;
