/**
 * Cache
 * @template T
 */
export default class Cache<T> {
    private store;
    constructor();
    /**
     * The function checks if a given key exists in an object and returns a boolean
     * value.
     * @param {string} key - Cache ID
     * @returns A boolean
     */
    exists(key: string): boolean;
    /**
     * This function retrieves a value from a store based on a given key, and returns
     * null if the key does not exist.
     * @param {string} key - Cache ID
     * @returns If it exists, it returns its value, otherwise null.
     */
    get(key: string): T | null;
    /**
     * This function sets a key-value pair in a store and returns true if successful,
     * false if the key already exists.
     * @param {string} key - Cache ID
     * @param {T} value - Cache value
     * @returns A boolean, indicating if the operation has been successfully.
     */
    set(key: string, value: T): boolean;
    /**
     * The function resets the store object and returns the instance of the class.
     * @returns this
     */
    reset(): this;
}
/**
 * This function takes a string key and returns its MD5 hash value as a string.
 * @param {string} key - Cache ID
 * @returns A MD5 hash
 */
export declare function hashCacheKey(key: string): string;
