interface IColorConvert {
    rgba: () => IColor;
    hsl: () => IColor;
    twCode: () => IColor;
}
export interface IColor extends IColorConvert {
    toArray: () => number[];
}
type HSL = [number, number, number];
export declare class ColorRGBA implements IColor {
    private _r;
    private _g;
    private _b;
    private _a;
    constructor(r: number, g: number, b: number, a: number);
    set r(value: number);
    set g(value: number);
    set b(value: number);
    set a(value: number);
    get r(): number;
    get g(): number;
    get b(): number;
    get a(): number;
    toArray(): number[];
    rgba(): IColor;
    hsl(): IColor;
    twCode(): IColor;
    get average(): number;
    /**
     * The function sets the red, green, and blue values of an image to their average
     * value, resulting in a black and white effect.
     * @returns this
     */
    blackAndWhite(): this;
    /**
     * The function applies a color to an object by adjusting its RGBA values based
     * on the input color.
     * @param {ColorRGBA} color - RGBA color
     * @returns
     */
    applyColor(color: ColorRGBA): this;
}
export declare class ColorRGB extends ColorRGBA implements IColor {
    constructor(r: number, g: number, b: number);
}
export declare class ColorHSL implements IColor {
    private _h;
    private _s;
    private _l;
    constructor(h: number, s: number, l: number);
    set h(value: number);
    set s(value: number);
    set l(value: number);
    get h(): number;
    get s(): number;
    get l(): number;
    toArray(): HSL;
    rgba(): IColor;
    hsl(): IColor;
    /**
     * TODO: Upgrade
     * @returns
     */
    twCode(): IColor;
}
export declare class ColorCode implements IColor {
    readonly code: number;
    constructor(value: number);
    toArray(): HSL;
    rgba(): IColor;
    hsl(): IColor;
    twCode(): IColor;
}
export {};
